app.components.x-avatar-group.model


attr-directioncljs


attr-disabledcljs


attr-labelcljs


attr-maxcljs


attr-overlapcljs


attr-sizecljs


compute-visible-hiddencljs

(compute-visible-hidden total max)

Given total item count and optional max, return [visible-count hidden-count].

Given total item count and optional max, return [visible-count hidden-count].
raw docstring

default-directioncljs


default-overlapcljs


default-sizecljs


normalizecljs

(normalize {:keys [size-raw overlap-raw max-raw direction-raw disabled-present?
                   label-raw]})

normalize-labelcljs

(normalize-label s)

observed-attributescljs


overlap-margincljs


parse-bool-attrcljs

(parse-bool-attr s)

parse-directioncljs

(parse-direction s)

parse-maxcljs

(parse-max s)

parse-overlapcljs

(parse-overlap s)

parse-sizecljs

(parse-size s)

property-apicljs


tag-namecljs

cljdoc builds & hosts documentation for Clojure/Script libraries