app.components.x-breadcrumbs.model


attr-aria-describedbycljs


attr-aria-labelcljs


attr-disabledcljs


attr-items-aftercljs


attr-items-beforecljs


attr-max-itemscljs


attr-preserve-aria-currentcljs


attr-separatorcljs


attr-sizecljs


attr-variantcljs


attr-wrapcljs


build-plancljs

(build-plan total max-items items-before items-after)

Return a map describing which items to display and where the ellipsis goes.

Returns: {:visible [0 1 4 5] ; indices of visible items in order :ellipsis-at 2 ; insert ellipsis before this position in :visible (-1 = none) :total 6}

Return a map describing which items to display and where the ellipsis goes.

Returns:
{:visible     [0 1 4 5]  ; indices of visible items in order
 :ellipsis-at 2          ; insert ellipsis before this position in :visible (-1 = none)
 :total       6}
raw docstring

default-items-aftercljs


default-items-beforecljs


default-separatorcljs


default-sizecljs


default-variantcljs


normalizecljs

(normalize {:keys [separator-raw size-raw variant-raw wrap-raw max-items-raw
                   items-before-raw items-after-raw disabled-present?
                   preserve-aria-current-present? aria-label-raw
                   aria-describedby-raw]})

normalize-separatorcljs

(normalize-separator s)

observed-attributescljs


parse-bool-attrcljs

(parse-bool-attr s)

parse-pos-intcljs

(parse-pos-int s fallback)

Parse string to positive integer ≥ 1, returning fallback on failure.

Parse string to positive integer ≥ 1, returning `fallback` on failure.
raw docstring

parse-pos-int-or-nilcljs

(parse-pos-int-or-nil s)

Parse string to positive integer ≥ 1, returning nil on failure.

Parse string to positive integer ≥ 1, returning nil on failure.
raw docstring

parse-sizecljs

(parse-size s)

parse-variantcljs

(parse-variant s)

property-apicljs


tag-namecljs

cljdoc builds & hosts documentation for Clojure/Script libraries