(cancel-request-detail reason)Build the x-cancel-dialogue-cancel-request CustomEvent detail.
Build the x-cancel-dialogue-cancel-request CustomEvent detail.
(confirm-request-detail)Build the x-cancel-dialogue-confirm-request CustomEvent detail.
Build the x-cancel-dialogue-confirm-request CustomEvent detail.
(normalize {:keys [open-present? disabled-present? headline-raw message-raw
confirm-text-raw cancel-text-raw danger-present?
portal-raw]})Produce a normalized view-model map from raw attribute values.
Produce a normalized view-model map from raw attribute values.
(parse-bool-attr s)Returns true if the attr value indicates presence (not nil), false otherwise.
Returns true if the attr value indicates presence (not nil), false otherwise.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |