app.components.x-chip.model


attr-disabledcljs


attr-labelcljs


attr-removablecljs


attr-valuecljs


effective-valuecljs

(effective-value label value-raw)

Returns value-raw when it is a non-nil, non-empty string; else falls back to label.

Returns value-raw when it is a non-nil, non-empty string; else falls back to label.
raw docstring

event-removecljs


normalizecljs

(normalize {:keys [label-raw value-raw removable-raw disabled-present?]})

Converts raw attribute strings to a clean view model. disabled-present? should be boolean: (.hasAttribute el attr-disabled)

Converts raw attribute strings to a clean view model.
disabled-present? should be boolean: (.hasAttribute el attr-disabled)
raw docstring

observed-attributescljs


parse-bool-default-truecljs

(parse-bool-default-true s)

nil (attribute absent) → true. 'false' or '0' → false. Anything else → true.

nil (attribute absent) → true.
'false' or '0' → false.
Anything else → true.
raw docstring

property-apicljs


removal-eligible?cljs

(removal-eligible? {:keys [removable? disabled?]})

True when the chip can be removed by the user: removable and not disabled.

True when the chip can be removed by the user: removable and not disabled.
raw docstring

remove-detailcljs

(remove-detail {:keys [value label]})

Builds the JS detail object for x-chip-remove events.

Builds the JS detail object for x-chip-remove events.
raw docstring

tag-namecljs

cljdoc builds & hosts documentation for Clojure/Script libraries