app.components.x-currency-field.model


attr-currencycljs


attr-disabledcljs


attr-errorcljs


attr-hintcljs


attr-labelcljs


attr-localecljs


attr-maxcljs


attr-mincljs


attr-namecljs


attr-placeholdercljs


attr-readonlycljs


attr-requiredcljs


attr-valuecljs


event-changecljs


event-inputcljs


event-schemacljs


normalizecljs

(normalize {:keys [name-raw value-raw currency-raw locale-raw min-raw max-raw
                   placeholder-raw label-raw hint-raw error-raw
                   disabled-present? required-present? readonly-present?]})

Derives a complete view-model map from raw attribute values.

Derives a complete view-model map from raw attribute values.
raw docstring

normalize-currencycljs

(normalize-currency raw)

observed-attributescljs


property-apicljs


tag-namecljs


validation-messagecljs

(validation-message {:keys [value min max]})

Returns a computed validation error string or empty string. Priority: badInput > rangeUnderflow > rangeOverflow.

Returns a computed validation error string or empty string.
Priority: badInput > rangeUnderflow > rangeOverflow.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries