app.components.x-fieldset.model


attr-aria-describedbycljs


attr-aria-labelcljs


attr-disabledcljs


attr-legendcljs


normalizecljs

(normalize {:keys [legend-raw disabled-present? aria-label-raw
                   aria-describedby-raw]})

Derives a complete view-model map from raw attribute values.

Derives a complete view-model map from raw attribute values.
raw docstring

observed-attributescljs


parse-bool-attrcljs

(parse-bool-attr s)

Returns true if attribute is present and not equal to "false".

Returns true if attribute is present and not equal to "false".
raw docstring

property-apicljs


tag-namecljs

cljdoc builds & hosts documentation for Clojure/Script libraries