app.components.x-radio.model


attr-aria-describedbycljs


attr-aria-labelcljs


attr-aria-labelledbycljs


attr-checkedcljs


attr-disabledcljs


attr-namecljs


attr-readonlycljs


attr-requiredcljs


attr-valuecljs


event-changecljs


event-change-requestcljs


event-schemacljs


normalizecljs

(normalize {:keys [checked-present? disabled-present? readonly-present?
                   required-present? name-raw value-raw aria-label-raw
                   aria-describedby-raw aria-labelledby-raw]})

Derives a complete view-model map from raw attribute presence/values.

Derives a complete view-model map from raw attribute presence/values.
raw docstring

observed-attributescljs


parse-bool-attrcljs

(parse-bool-attr s)

Returns true if the attribute is present and not equal to "false".

Returns true if the attribute is present and not equal to "false".
raw docstring

property-apicljs


radio-valuecljs

(radio-value raw)

Returns the raw value string, or "on" if nil.

Returns the raw value string, or "on" if nil.
raw docstring

tag-namecljs


valid?cljs

(valid? required? checked?)

Returns true when the field satisfies its required constraint.

Returns true when the field satisfies its required constraint.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries