app.components.x-select.model


allowed-sizescljs

source

attr-disabledcljs

source

attr-namecljs

source

attr-placeholdercljs

source

attr-requiredcljs

source

attr-sizecljs

source

attr-valuecljs

source

default-sizecljs

source

event-schemacljs

source

event-select-changecljs

source

normalizecljs

(normalize {:keys [disabled-present? required-present? size-raw placeholder-raw
                   value-raw name-raw]})

Derives a complete view-model map from raw attribute presence/values.

Derives a complete view-model map from raw attribute presence/values.
sourceraw docstring

normalize-enumcljs

(normalize-enum value allowed default-value)

Returns value if it is in allowed, otherwise default-value.

Returns value if it is in allowed, otherwise default-value.
sourceraw docstring

normalize-sizecljs

(normalize-size v)
source

observed-attributescljs

source

property-apicljs

source

tag-namecljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries