app.components.x-spacer.model


attr-axiscljs


attr-growcljs


attr-sizecljs


default-axiscljs


default-sizecljs


normalizecljs

(normalize {:keys [size-raw axis-raw grow-raw]})

Normalise raw attribute inputs into a stable view-model map.

Input keys: :size-raw string | nil :axis-raw string | nil :grow-raw string | nil

Output keys: :size string — CSS length value :axis string — 'vertical' | 'horizontal' :grow? boolean — true when grow attribute is present

Normalise raw attribute inputs into a stable view-model map.

Input keys:
  :size-raw   string | nil
  :axis-raw   string | nil
  :grow-raw   string | nil

Output keys:
  :size   string   — CSS length value
  :axis   string   — 'vertical' | 'horizontal'
  :grow?  boolean  — true when grow attribute is present
raw docstring

observed-attributescljs


parse-axiscljs

(parse-axis s)

Normalise axis attribute. Unknown / nil values fall back to 'vertical'.

Normalise axis attribute. Unknown / nil values fall back to 'vertical'.
raw docstring

parse-growcljs

(parse-grow s)

Returns true when the grow attribute is present and not explicitly 'false'. grow is false when absent (nil), true when present (empty string or any value other than 'false').

Returns true when the grow attribute is present and not explicitly 'false'.
grow is false when absent (nil), true when present (empty string or any value
other than 'false').
raw docstring

parse-sizecljs

(parse-size s)

Returns the size value, or the default when nil/blank.

Returns the size value, or the default when nil/blank.
raw docstring

property-apicljs


tag-namecljs

cljdoc builds & hosts documentation for Clojure/Script libraries