app.components.x-stepper.model


attr-currentcljs


attr-disabledcljs


attr-orientationcljs


attr-sizecljs


attr-stepscljs


change-detailcljs

(change-detail from to)

Build event detail map for an x-stepper-change event.

Build event detail map for an x-stepper-change event.
raw docstring

clamp-currentcljs

(clamp-current current-idx steps-count)

Clamp current to [0, steps-count-1], or 0 when there are no steps.

Clamp current to [0, steps-count-1], or 0 when there are no steps.
raw docstring

event-changecljs


event-schemacljs


normalizecljs

(normalize {:keys [steps-raw current-raw orientation-raw size-raw disabled?]})

Normalize raw attribute inputs into a stable view-model map.

Input keys: :steps-raw string | nil :current-raw string | nil :orientation-raw string | nil :size-raw string | nil :disabled? boolean

Output keys: :steps [{:label string :description string|nil} ...] :current int (clamped) :orientation :horizontal | :vertical :size :sm | :md | :lg :disabled? boolean

Normalize raw attribute inputs into a stable view-model map.

Input keys:
  :steps-raw       string | nil
  :current-raw     string | nil
  :orientation-raw string | nil
  :size-raw        string | nil
  :disabled?       boolean

Output keys:
  :steps       [{:label string :description string|nil} ...]
  :current     int  (clamped)
  :orientation :horizontal | :vertical
  :size        :sm | :md | :lg
  :disabled?   boolean
raw docstring

observed-attributescljs


orientation->attrcljs

(orientation->attr o)

parse-currentcljs

(parse-current s)

Parse current-step attribute to a non-negative integer, defaulting to 0.

Parse current-step attribute to a non-negative integer, defaulting to 0.
raw docstring

parse-orientationcljs

(parse-orientation s)

parse-sizecljs

(parse-size s)

parse-stepscljs

(parse-steps s)

Parse the steps attribute value into a vector of {:label string :description string|nil}.

Accepted formats:

  • Positive integer string "3" → [{:label "Step 1"} {:label "Step 2"} {:label "Step 3"}]
  • JSON array string "[{"label":"One"}]" Unrecognised / nil → [].
Parse the steps attribute value into a vector of {:label string :description string|nil}.

Accepted formats:
  - Positive integer string  "3"  → [{:label "Step 1"} {:label "Step 2"} {:label "Step 3"}]
  - JSON array string        "[{\"label\":\"One\"}]"
Unrecognised / nil → [].
raw docstring

property-apicljs


size->attrcljs

(size->attr s)

state->attrcljs

(state->attr state)

step-statecljs

(step-state i current-idx)

Return :complete, :current, or :upcoming for the step at index i.

Return :complete, :current, or :upcoming for the step at index i.
raw docstring

tag-namecljs

cljdoc builds & hosts documentation for Clojure/Script libraries