app.components.x-switch.model


attr-aria-describedbycljs


attr-aria-labelcljs


attr-aria-labelledbycljs


attr-checkedcljs


attr-disabledcljs


attr-namecljs


attr-readonlycljs


attr-requiredcljs


attr-valuecljs


event-changecljs


event-change-requestcljs


event-schemacljs


normalizecljs

(normalize {:keys [checked-present? disabled-present? readonly-present?
                   required-present? name-raw value-raw aria-label-raw
                   aria-describedby-raw aria-labelledby-raw]})

Derives a complete view-model map from raw attribute presence/values.

Input keys: :checked-present? boolean :disabled-present? boolean :readonly-present? boolean :required-present? boolean :name-raw string | nil :value-raw string | nil :aria-label-raw string | nil :aria-describedby-raw string | nil :aria-labelledby-raw string | nil

Output keys: :checked? boolean :disabled? boolean :readonly? boolean :required? boolean :valid? boolean :name string | nil :value string :aria-label string | nil :aria-describedby string | nil :aria-labelledby string | nil :aria-checked "true" | "false"

Derives a complete view-model map from raw attribute presence/values.

Input keys:
  :checked-present?      boolean
  :disabled-present?     boolean
  :readonly-present?     boolean
  :required-present?     boolean
  :name-raw              string | nil
  :value-raw             string | nil
  :aria-label-raw        string | nil
  :aria-describedby-raw  string | nil
  :aria-labelledby-raw   string | nil

Output keys:
  :checked?          boolean
  :disabled?         boolean
  :readonly?         boolean
  :required?         boolean
  :valid?            boolean
  :name              string | nil
  :value             string
  :aria-label        string | nil
  :aria-describedby  string | nil
  :aria-labelledby   string | nil
  :aria-checked      "true" | "false"
raw docstring

observed-attributescljs


parse-bool-attrcljs

(parse-bool-attr s)

Returns true if the attribute is present (non-nil) and not equal to "false".

Returns true if the attribute is present (non-nil) and not equal to "false".
raw docstring

property-apicljs


switch-valuecljs

(switch-value raw)

Returns the raw value string, or "on" if nil.

Returns the raw value string, or "on" if nil.
raw docstring

tag-namecljs


valid?cljs

(valid? required? checked?)

Returns true when the field satisfies its required constraint.

Returns true when the field satisfies its required constraint.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries