app.components.x-table-cell.model


aria-sort-valuecljs

(aria-sort-value {:keys [sortable? sort-direction]})

Return aria-sort string or nil if not applicable. Set only when sortable is true or sort-direction is not "none".

Return aria-sort string or nil if not applicable.
Set only when sortable is true or sort-direction is not "none".
raw docstring

attr-aligncljs


attr-col-spancljs


attr-disabledcljs


attr-row-spancljs


attr-scopecljs


attr-sort-directioncljs


attr-sortablecljs


attr-stickycljs


attr-truncatecljs


attr-typecljs


attr-valigncljs


connected-detailcljs

(connected-detail {:keys [type scope col-span row-span align]})

Build the event detail map for x-table-cell-connected.

Build the event detail map for x-table-cell-connected.
raw docstring

event-connectedcljs


event-disconnectedcljs


event-schemacljs


event-sortcljs


next-sort-directioncljs

(next-sort-direction current)

Cycle sort direction: none → asc → desc → none.

Cycle sort direction: none → asc → desc → none.
raw docstring

normalizecljs

(normalize {:keys [type-raw scope-raw align-raw valign-raw col-span-raw
                   row-span-raw truncate? sticky-raw sortable?
                   sort-direction-raw disabled?]})

Produce a canonical view-model map from raw attribute inputs.

Input keys: :type-raw string | nil :scope-raw string | nil :align-raw string | nil :valign-raw string | nil :col-span-raw string | nil :row-span-raw string | nil :truncate? boolean :sticky-raw string | nil :sortable? boolean :sort-direction-raw string | nil :disabled? boolean

Output keys mirror the attribute semantics with parsed/normalised values.

Produce a canonical view-model map from raw attribute inputs.

Input keys:
  :type-raw           string | nil
  :scope-raw          string | nil
  :align-raw          string | nil
  :valign-raw         string | nil
  :col-span-raw       string | nil
  :row-span-raw       string | nil
  :truncate?          boolean
  :sticky-raw         string | nil
  :sortable?          boolean
  :sort-direction-raw string | nil
  :disabled?          boolean

Output keys mirror the attribute semantics with parsed/normalised values.
raw docstring

observed-attributescljs


parse-aligncljs

(parse-align s)

Normalise align attribute. Unknown/nil → "start".

Normalise align attribute. Unknown/nil → "start".
raw docstring

parse-scopecljs

(parse-scope s)

Normalise scope attribute. Unknown/nil → "col".

Normalise scope attribute. Unknown/nil → "col".
raw docstring

parse-sort-directioncljs

(parse-sort-direction s)

Normalise sort-direction attribute. Unknown/nil → "none".

Normalise sort-direction attribute. Unknown/nil → "none".
raw docstring

parse-spancljs

(parse-span s)

Parse a col-span or row-span attribute to a positive integer. Invalid/nil → 1.

Parse a col-span or row-span attribute to a positive integer. Invalid/nil → 1.
raw docstring

parse-stickycljs

(parse-sticky s)

Normalise sticky attribute. Unknown/nil → "none".

Normalise sticky attribute. Unknown/nil → "none".
raw docstring

parse-typecljs

(parse-type s)

Normalise type attribute. Unknown/nil → "data".

Normalise type attribute. Unknown/nil → "data".
raw docstring

parse-valigncljs

(parse-valign s)

Normalise valign attribute. Unknown/nil → "middle".

Normalise valign attribute. Unknown/nil → "middle".
raw docstring

property-apicljs


role-for-cellcljs

(role-for-cell {:keys [type scope]})

Return the ARIA role string for the host element based on type and scope.

Return the ARIA role string for the host element based on type and scope.
raw docstring

slot-sort-iconcljs


sort-btn-aria-labelcljs

(sort-btn-aria-label current-direction)

Return the aria-label for the sort button describing the action that will occur.

Return the aria-label for the sort button describing the action that will occur.
raw docstring

sort-btn-tabindexcljs

(sort-btn-tabindex {:keys [type sortable? disabled?]})

Returns "0" when the sort button should be keyboard-focusable, else "-1".

Returns "0" when the sort button should be keyboard-focusable, else "-1".
raw docstring

sort-btn-visible?cljs

(sort-btn-visible? {:keys [type sortable?]})

Sort button is visible only for header cells with sortable=true.

Sort button is visible only for header cells with sortable=true.
raw docstring

tag-namecljs

cljdoc builds & hosts documentation for Clojure/Script libraries