baredom.components.x-avatar-group.model


attr-directioncljs

source

attr-disabledcljs

source

attr-labelcljs

source

attr-maxcljs

source

attr-overlapcljs

source

attr-sizecljs

source

compute-visible-hiddencljs

(compute-visible-hidden total max)

Given total item count and optional max, return [visible-count hidden-count].

Given total item count and optional max, return [visible-count hidden-count].
sourceraw docstring

default-directioncljs

source

default-overlapcljs

source

default-sizecljs

source

normalizecljs

(normalize {:keys [size-raw overlap-raw max-raw direction-raw disabled-present?
                   label-raw]})
source

normalize-labelcljs

(normalize-label s)
source

observed-attributescljs

source

overlap-margincljs

source

parse-bool-attrcljs

(parse-bool-attr s)
source

parse-directioncljs

(parse-direction s)
source

parse-maxcljs

(parse-max s)
source

parse-overlapcljs

(parse-overlap s)
source

parse-sizecljs

(parse-size s)
source

property-apicljs

source

tag-namecljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries