baredom.components.x-bento-item.model


attr-col-spancljs

source

attr-ordercljs

source

attr-row-spancljs

source

derive-statecljs

(derive-state {:keys [col-span row-span order]})
source

event-schemacljs

source

normalize-ordercljs

(normalize-order v)

Parse order attribute to integer, or nil if absent/invalid.

Parse order attribute to integer, or nil if absent/invalid.
sourceraw docstring

normalize-spancljs

(normalize-span v)

Parse span attribute to integer clamped 1–6, default 1.

Parse span attribute to integer clamped 1–6, default 1.
sourceraw docstring

observed-attributescljs

source

property-apicljs

source

tag-namecljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries