baredom.components.x-breadcrumbs.model


attr-aria-describedbycljs

source

attr-aria-labelcljs

source

attr-disabledcljs

source

attr-items-aftercljs

source

attr-items-beforecljs

source

attr-max-itemscljs

source

attr-preserve-aria-currentcljs

source

attr-separatorcljs

source

attr-sizecljs

source

attr-variantcljs

source

attr-wrapcljs

source

build-plancljs

(build-plan total max-items items-before items-after)

Return a map describing which items to display and where the ellipsis goes.

Returns: {:visible [0 1 4 5] ; indices of visible items in order :ellipsis-at 2 ; insert ellipsis before this position in :visible (-1 = none) :total 6}

Return a map describing which items to display and where the ellipsis goes.

Returns:
{:visible     [0 1 4 5]  ; indices of visible items in order
 :ellipsis-at 2          ; insert ellipsis before this position in :visible (-1 = none)
 :total       6}
sourceraw docstring

default-items-aftercljs

source

default-items-beforecljs

source

default-separatorcljs

source

default-sizecljs

source

default-variantcljs

source

normalizecljs

(normalize {:keys [separator-raw size-raw variant-raw wrap-raw max-items-raw
                   items-before-raw items-after-raw disabled-present?
                   preserve-aria-current-present? aria-label-raw
                   aria-describedby-raw]})
source

normalize-separatorcljs

(normalize-separator s)
source

observed-attributescljs

source

parse-bool-attrcljs

(parse-bool-attr s)
source

parse-pos-intcljs

(parse-pos-int s fallback)

Parse string to positive integer ≥ 1, returning fallback on failure.

Parse string to positive integer ≥ 1, returning `fallback` on failure.
sourceraw docstring

parse-pos-int-or-nilcljs

(parse-pos-int-or-nil s)

Parse string to positive integer ≥ 1, returning nil on failure.

Parse string to positive integer ≥ 1, returning nil on failure.
sourceraw docstring

parse-sizecljs

(parse-size s)
source

parse-variantcljs

(parse-variant s)
source

property-apicljs

source

tag-namecljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries