baredom.components.x-carousel.model


attr-aria-labelcljs

source

attr-arrowscljs

source

attr-autoplaycljs

source

attr-currentcljs

source

attr-directioncljs

source

attr-disabledcljs

source

attr-dotscljs

source

attr-intervalcljs

source

attr-loopcljs

source

attr-peekcljs

source

attr-transitioncljs

source

can-go-next?cljs

(can-go-next? {:keys [current loop? slide-count disabled?]})
source

can-go-prev?cljs

(can-go-prev? {:keys [current loop? slide-count disabled?]})
source

clamp-indexcljs

(clamp-index idx cnt)

Clamp idx within [0, count-1]. Returns 0 when count <= 0.

Clamp idx within [0, count-1]. Returns 0 when count <= 0.
sourceraw docstring

css-arrow-bgcljs

source

css-arrow-colorcljs

source

css-arrow-hover-bgcljs

source

css-arrow-sizecljs

source

css-dot-active-colorcljs

source

css-dot-colorcljs

source

css-dot-sizecljs

source

css-gapcljs

source

css-heightcljs

source

css-radiuscljs

source

css-transition-durationcljs

source

default-currentcljs

source

default-directioncljs

source

default-intervalcljs

source

default-peekcljs

source

default-transitioncljs

source

drag-threshold-pxcljs

source

event-changecljs

source

event-schemacljs

source

next-indexcljs

(next-index {:keys [current loop? slide-count]})
source

next-key?cljs

(next-key? direction key)

Returns true if key is a 'next' key for the given direction.

Returns true if key is a 'next' key for the given direction.
sourceraw docstring

normalizecljs

(normalize {:keys [autoplay-present? interval-raw loop-present? arrows-raw
                   dots-raw disabled-present? current-raw transition-raw
                   direction-raw peek-raw aria-label-raw slide-count]})

Normalise raw attribute inputs into a stable view-model map.

Normalise raw attribute inputs into a stable view-model map.
sourceraw docstring

observed-attributescljs

source

parse-bool-default-truecljs

(parse-bool-default-true s)

Parse an attribute that is true when absent or empty, false only when "false".

Parse an attribute that is true when absent or empty, false only when "false".
sourceraw docstring

parse-directioncljs

(parse-direction s)

Normalise direction attribute to "horizontal" or "vertical".

Normalise direction attribute to "horizontal" or "vertical".
sourceraw docstring

parse-non-neg-intcljs

(parse-non-neg-int s fallback)

Parse a string to a non-negative integer. Returns fallback on failure.

Parse a string to a non-negative integer. Returns fallback on failure.
sourceraw docstring

parse-peekcljs

(parse-peek s)

Validate a CSS length string for peek. Returns default on invalid.

Validate a CSS length string for peek. Returns default on invalid.
sourceraw docstring

parse-pos-intcljs

(parse-pos-int s fallback min-val)

Parse a string to a positive integer >= min-val. Returns fallback on failure.

Parse a string to a positive integer >= min-val. Returns fallback on failure.
sourceraw docstring

parse-transitioncljs

(parse-transition s)

Normalise transition attribute to "slide" or "fade".

Normalise transition attribute to "slide" or "fade".
sourceraw docstring

prev-indexcljs

(prev-index {:keys [current loop? slide-count]})
source

prev-key?cljs

(prev-key? direction key)

Returns true if key is a 'previous' key for the given direction.

Returns true if key is a 'previous' key for the given direction.
sourceraw docstring

property-apicljs

source

show-arrows?cljs

(show-arrows? {:keys [arrows? slide-count]})
source

show-dots?cljs

(show-dots? {:keys [dots? slide-count]})
source

single-slide?cljs

(single-slide? {:keys [slide-count]})
source

snap-directioncljs

(snap-direction delta velocity)

Given drag delta (positive = toward prev) and velocity (px/ms, positive = toward prev), returns :prev, :next, or :stay.

Given drag delta (positive = toward prev) and velocity (px/ms, positive = toward prev),
returns :prev, :next, or :stay.
sourceraw docstring

tag-namecljs

source

velocity-thresholdcljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries