baredom.components.x-collapse.model


attr-disabledcljs

source

attr-duration-mscljs

source

attr-headercljs

source

attr-opencljs

source

clampcljs

(clamp n lo hi)

Clamps n to the range [lo hi].

Clamps n to the range [lo hi].
sourceraw docstring

default-duration-mscljs

source

event-changecljs

source

event-schemacljs

source

event-togglecljs

source

normalizecljs

(normalize {:keys [open-present? disabled-present? header-raw duration-ms-raw]})

Derives a complete view-model map from raw attribute presence/values.

Derives a complete view-model map from raw attribute presence/values.
sourceraw docstring

observed-attributescljs

source

parse-int-poscljs

(parse-int-pos s)

Parses s as a positive integer. Returns nil if s is nil, not a number, or <= 0.

Parses s as a positive integer. Returns nil if s is nil, not a number, or <= 0.
sourceraw docstring

property-apicljs

source

slot-contentcljs

source

tag-namecljs

source

toggle-detailcljs

(toggle-detail open? source)

Produces the CustomEvent detail object for toggle/change events.

Produces the CustomEvent detail object for toggle/change events.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries