baredom.components.x-combobox.model


allowed-placementscljs

source

attr-disabledcljs

source

attr-errorcljs

source

attr-namecljs

source

attr-opencljs

source

attr-placeholdercljs

source

attr-placementcljs

source

attr-requiredcljs

source

attr-valuecljs

source

default-placementcljs

source

empty-keycljs

source

empty-messagecljs

source

event-changecljs

source

event-change-requestcljs

source

event-inputcljs

source

event-schemacljs

source

event-togglecljs

source

filter-optionscljs

(filter-options options query)

Filters options by case-insensitive substring match on label. Returns all options when query is nil or empty.

Filters options by case-insensitive substring match on label.
Returns all options when query is nil or empty.
sourceraw docstring

find-option-by-valuecljs

(find-option-by-value options value)

Returns the first option map where :value matches, or nil.

Returns the first option map where :value matches, or nil.
sourceraw docstring

highlight-matchcljs

(highlight-match label query)

Splits label around the first case-insensitive match of query. Returns {:before :match :after} or nil if no match.

Splits label around the first case-insensitive match of query.
Returns {:before :match :after} or nil if no match.
sourceraw docstring

method-apicljs

source

next-active-idxcljs

(next-active-idx n active-idx)

Advance active-idx forward, wrapping.

Advance active-idx forward, wrapping.
sourceraw docstring

normalizecljs

(normalize {:keys [value-raw placeholder-raw name-raw disabled-present?
                   required-present? open-present? placement-raw error-raw]})

Derives a complete view-model map from raw attribute presence/values.

Derives a complete view-model map from raw attribute presence/values.
sourceraw docstring

normalize-placementcljs

(normalize-placement s)

Normalizes raw placement string. Falls back to default-placement if invalid or nil.

Normalizes raw placement string. Falls back to default-placement if invalid or nil.
sourceraw docstring

observed-attributescljs

source

prev-active-idxcljs

(prev-active-idx n active-idx)

Advance active-idx backward, wrapping.

Advance active-idx backward, wrapping.
sourceraw docstring

property-apicljs

source

shown-panelcljs

(shown-panel options query wanted-active-idx selected-value)

What the panel shows: :items, each with its key and the text of what it shows, and :active-id, the id of the active option or nil. With no option that matches query, the one item is the empty message. The key of an option is made of its value, so an option keeps its key while the query changes.

What the panel shows: `:items`, each with its key and the text of what it shows, and
`:active-id`, the id of the active option or nil. With no option that matches `query`, the
one item is the empty message. The key of an option is made of its value, so an option
keeps its key while the query changes.
sourceraw docstring

tag-namecljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries