baredom.components.x-currency-field.model


attr-currencycljs

source

attr-disabledcljs

source

attr-errorcljs

source

attr-hintcljs

source

attr-labelcljs

source

attr-localecljs

source

attr-maxcljs

source

attr-mincljs

source

attr-namecljs

source

attr-placeholdercljs

source

attr-readonlycljs

source

attr-requiredcljs

source

attr-valuecljs

source

event-changecljs

source

event-inputcljs

source

event-schemacljs

source

normalizecljs

(normalize {:keys [name-raw value-raw currency-raw locale-raw min-raw max-raw
                   placeholder-raw label-raw hint-raw error-raw
                   disabled-present? required-present? readonly-present?]})

Derives a complete view-model map from raw attribute values.

Derives a complete view-model map from raw attribute values.
sourceraw docstring

normalize-currencycljs

(normalize-currency raw)
source

observed-attributescljs

source

property-apicljs

source

tag-namecljs

source

validation-messagecljs

(validation-message {:keys [value min max]})

Returns a computed validation error string or empty string. Priority: badInput > rangeUnderflow > rangeOverflow.

Returns a computed validation error string or empty string.
Priority: badInput > rangeUnderflow > rangeOverflow.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries