baredom.components.x-form.model


allowed-autocompletecljs

source

attr-autocompletecljs

source

attr-loadingcljs

source

attr-novalidatecljs

source

bool-attr?cljs

(bool-attr? v)

Returns true when attribute is present and not literally "false".

Returns true when attribute is present and not literally "false".
sourceraw docstring

event-resetcljs

source

event-schemacljs

source

event-submitcljs

source

normalizecljs

(normalize {:keys [loading-raw novalidate-raw autocomplete-raw]})

Derives a complete view-model map from raw attribute values.

Derives a complete view-model map from raw attribute values.
sourceraw docstring

normalize-autocompletecljs

(normalize-autocomplete raw)
source

observed-attributescljs

source

property-apicljs

source

tag-namecljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries