baredom.components.x-i18n-provider.model


attr-fallback-localecljs

source

attr-localecljs

source

attr-srccljs

source

default-localecljs

source

event-changecljs

source

event-errorcljs

source

event-loadingcljs

source

event-schemacljs

source

method-apicljs

source

needs-fetch?cljs

(needs-fetch? old-m new-m)

Returns true when the locale or src changed between old and new models, indicating a new fetch is required.

Returns true when the locale or src changed between old and new models,
indicating a new fetch is required.
sourceraw docstring

normalizecljs

(normalize src locale fallback-locale)

Normalize raw attribute values into a model map.

Normalize raw attribute values into a model map.
sourceraw docstring

observed-attributescljs

source

property-apicljs

source

resolve-urlcljs

(resolve-url src locale)

Replace {locale} in the src pattern with the given locale. Returns nil if src or locale is blank.

Replace `{locale}` in the src pattern with the given locale.
Returns nil if src or locale is blank.
sourceraw docstring

tag-namecljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries