baredom.components.x-i18n-provider.x-i18n-provider


get-translationscljs

(get-translations el)

Returns the translations object stored on the provider element. Used by x-i18n children to resolve translation keys.

Returns the translations object stored on the provider element.
Used by x-i18n children to resolve translation keys.
sourceraw docstring

init!cljs

(init!)
source

set-translations!cljs

(set-translations! el translations)

Set translations on the provider element. Used by tests and for programmatic locale injection.

Set translations on the provider element.
Used by tests and for programmatic locale injection.
sourceraw docstring

translate-subtree!cljs

(translate-subtree! el)

Scan all descendants for data-i18n-{attr} attributes and set the corresponding real attribute from the current translations. Skips elements owned by nested x-i18n-provider elements.

Scan all descendants for data-i18n-{attr} attributes and set the
corresponding real attribute from the current translations.
Skips elements owned by nested x-i18n-provider elements.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries