baredom.components.x-particle-button.model


allowed-modescljs

source

allowed-sizescljs

source

allowed-typescljs

source

allowed-variantscljs

source

aria-busycljs

(aria-busy {:keys [loading]})
source

aria-labelcljs

(aria-label {:keys [label has-default-text?]})
source

attr-disabledcljs

source

attr-intensitycljs

source

attr-labelcljs

source

attr-loadingcljs

source

attr-modecljs

source

attr-particle-countcljs

source

attr-particle-sizecljs

source

attr-pressedcljs

source

attr-reassemble-speedcljs

source

attr-sizecljs

source

attr-typecljs

source

attr-variantcljs

source

clamp-intcljs

(clamp-int raw-str default-val min-val max-val)
source

default-intensitycljs

source

default-modecljs

source

default-particle-countcljs

source

default-particle-sizecljs

source

default-reassemble-speedcljs

source

default-sizecljs

source

default-typecljs

source

default-variantcljs

source

event-burstcljs

source

event-focus-visiblecljs

source

event-hover-endcljs

source

event-hover-startcljs

source

event-presscljs

source

event-press-endcljs

source

event-press-startcljs

source

event-reformcljs

source

event-schemacljs

source

interactive?cljs

(interactive? {:keys [disabled loading]})
source

mode-physicscljs

(mode-physics mode)

Returns physics configuration for a given mode.

Returns physics configuration for a given mode.
sourceraw docstring

normalize-enumcljs

(normalize-enum value allowed default-value)
source

normalize-intensitycljs

(normalize-intensity v)
source

normalize-modecljs

(normalize-mode value)
source

normalize-particle-countcljs

(normalize-particle-count v)
source

normalize-particle-sizecljs

(normalize-particle-size v)
source

normalize-reassemble-speedcljs

(normalize-reassemble-speed v)
source

normalize-sizecljs

(normalize-size value)
source

normalize-typecljs

(normalize-type value)
source

normalize-variantcljs

(normalize-variant value)
source

observed-attributescljs

source

particle-lifetime-rangecljs

(particle-lifetime-range ptype mode)

Returns [min-ms max-ms] for a particle type and mode.

Returns [min-ms max-ms] for a particle type and mode.
sourceraw docstring

particle-opacity-rangecljs

(particle-opacity-range ptype mode)

Returns [min max] opacity for a particle type and mode.

Returns [min max] opacity for a particle type and mode.
sourceraw docstring

particle-size-rangecljs

(particle-size-range ptype base-size mode)

Returns [min-size max-size] for a particle type given base particle-size and mode.

Returns [min-size max-size] for a particle type given base particle-size and mode.
sourceraw docstring

pick-particle-typecljs

(pick-particle-type rand-val mode-cfg)

Returns type-dust, type-fragment, or type-streak based on mode ratios.

Returns type-dust, type-fragment, or type-streak based on mode ratios.
sourceraw docstring

press-burst-velocitycljs

(press-burst-velocity px py bw bh base-speed spread rand-angle rand-speed)

Compute [vx vy] for a particle emitted from (px,py) with base-speed, spread half-angle, and random values [0,1).

Compute [vx vy] for a particle emitted from (px,py) with
base-speed, spread half-angle, and random values [0,1).
sourceraw docstring

property-apicljs

source

public-statecljs

(public-state {:keys [disabled loading pressed type variant size label mode
                      particle-count intensity particle-size reassemble-speed]})
source

random-edge-pointcljs

(random-edge-point w h rand-val)

Given button width w and height h and a random value [0,1), returns [x y nx ny] where (x,y) is on the perimeter and (nx,ny) is the outward normal.

Given button width w and height h and a random value [0,1),
returns [x y nx ny] where (x,y) is on the perimeter and
(nx,ny) is the outward normal.
sourceraw docstring

slot-defaultcljs

source

slot-icon-endcljs

source

slot-icon-startcljs

source

slot-spinnercljs

source

tag-namecljs

source

type-dustcljs

source

type-fragmentcljs

source

type-streakcljs

source

variant-visualscljs

(variant-visuals variant)

Returns visual-only configuration for a variant. Particle behavior is now controlled by mode, not variant.

Returns visual-only configuration for a variant.
Particle behavior is now controlled by mode, not variant.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries