baredom.components.x-radio.model


attr-aria-describedbycljs

source

attr-aria-labelcljs

source

attr-aria-labelledbycljs

source

attr-checkedcljs

source

attr-disabledcljs

source

attr-namecljs

source

attr-readonlycljs

source

attr-requiredcljs

source

attr-valuecljs

source

event-changecljs

source

event-change-requestcljs

source

event-schemacljs

source

normalizecljs

(normalize {:keys [checked-present? disabled-present? readonly-present?
                   required-present? name-raw value-raw aria-label-raw
                   aria-describedby-raw aria-labelledby-raw]})

Derives a complete view-model map from raw attribute presence/values.

Derives a complete view-model map from raw attribute presence/values.
sourceraw docstring

observed-attributescljs

source

parse-bool-attrcljs

(parse-bool-attr s)

Returns true if the attribute is present and not equal to "false".

Returns true if the attribute is present and not equal to "false".
sourceraw docstring

property-apicljs

source

radio-valuecljs

(radio-value raw)

Returns the raw value string, or "on" if nil.

Returns the raw value string, or "on" if nil.
sourceraw docstring

tag-namecljs

source

valid?cljs

(valid? required? checked?)

Returns true when the field satisfies its required constraint.

Returns true when the field satisfies its required constraint.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries