baredom.components.x-stepper.model


attr-currentcljs

source

attr-disabledcljs

source

attr-orientationcljs

source

attr-sizecljs

source

attr-stepscljs

source

change-detailcljs

(change-detail from to)

Build event detail map for an x-stepper-change event.

Build event detail map for an x-stepper-change event.
sourceraw docstring

clamp-currentcljs

(clamp-current current-idx steps-count)

Clamp current to [0, steps-count-1], or 0 when there are no steps.

Clamp current to [0, steps-count-1], or 0 when there are no steps.
sourceraw docstring

event-changecljs

source

event-schemacljs

source

normalizecljs

(normalize {:keys [steps-raw current-raw orientation-raw size-raw disabled?]})

Normalize raw attribute inputs into a stable view-model map.

Input keys: :steps-raw string | nil :current-raw string | nil :orientation-raw string | nil :size-raw string | nil :disabled? boolean

Output keys: :steps [{:label string :description string|nil} ...] :current int (clamped) :orientation :horizontal | :vertical :size :sm | :md | :lg :disabled? boolean

Normalize raw attribute inputs into a stable view-model map.

Input keys:
  :steps-raw       string | nil
  :current-raw     string | nil
  :orientation-raw string | nil
  :size-raw        string | nil
  :disabled?       boolean

Output keys:
  :steps       [{:label string :description string|nil} ...]
  :current     int  (clamped)
  :orientation :horizontal | :vertical
  :size        :sm | :md | :lg
  :disabled?   boolean
sourceraw docstring

observed-attributescljs

source

orientation->attrcljs

(orientation->attr o)
source

parse-currentcljs

(parse-current s)

Parse current-step attribute to a non-negative integer, defaulting to 0.

Parse current-step attribute to a non-negative integer, defaulting to 0.
sourceraw docstring

parse-orientationcljs

(parse-orientation s)
source

parse-sizecljs

(parse-size s)
source

parse-stepscljs

(parse-steps s)

Parse the steps attribute value into a vector of {:label string :description string|nil}.

Accepted formats:

  • Positive integer string "3" → [{:label "Step 1"} {:label "Step 2"} {:label "Step 3"}]
  • JSON array string "[{"label":"One"}]" Unrecognised / nil → [].
Parse the steps attribute value into a vector of {:label string :description string|nil}.

Accepted formats:
  - Positive integer string  "3"  → [{:label "Step 1"} {:label "Step 2"} {:label "Step 3"}]
  - JSON array string        "[{\"label\":\"One\"}]"
Unrecognised / nil → [].
sourceraw docstring

property-apicljs

source

size->attrcljs

(size->attr s)
source

state->attrcljs

(state->attr state)
source

step-statecljs

(step-state i current-idx)

Return :complete, :current, or :upcoming for the step at index i.

Return :complete, :current, or :upcoming for the step at index i.
sourceraw docstring

tag-namecljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries