baredom.components.x-table-cell.model


aria-sort-valuecljs

(aria-sort-value {:keys [sortable? sort-direction]})

Return aria-sort string or nil if not applicable. Set only when sortable is true or sort-direction is not "none".

Return aria-sort string or nil if not applicable.
Set only when sortable is true or sort-direction is not "none".
sourceraw docstring

attr-aligncljs

source

attr-col-spancljs

source

attr-disabledcljs

source

attr-row-spancljs

source

attr-scopecljs

source

attr-sort-directioncljs

source

attr-sortablecljs

source

attr-stickycljs

source

attr-truncatecljs

source

attr-typecljs

source

attr-valigncljs

source

connected-detailcljs

(connected-detail {:keys [type scope col-span row-span align]})

Build the event detail map for x-table-cell-connected.

Build the event detail map for x-table-cell-connected.
sourceraw docstring

event-connectedcljs

source

event-disconnectedcljs

source

event-schemacljs

source

event-sortcljs

source

next-sort-directioncljs

(next-sort-direction current)

Cycle sort direction: none → asc → desc → none.

Cycle sort direction: none → asc → desc → none.
sourceraw docstring

normalizecljs

(normalize {:keys [type-raw scope-raw align-raw valign-raw col-span-raw
                   row-span-raw truncate? sticky-raw sortable?
                   sort-direction-raw disabled?]})

Produce a canonical view-model map from raw attribute inputs.

Input keys: :type-raw string | nil :scope-raw string | nil :align-raw string | nil :valign-raw string | nil :col-span-raw string | nil :row-span-raw string | nil :truncate? boolean :sticky-raw string | nil :sortable? boolean :sort-direction-raw string | nil :disabled? boolean

Output keys mirror the attribute semantics with parsed/normalised values.

Produce a canonical view-model map from raw attribute inputs.

Input keys:
  :type-raw           string | nil
  :scope-raw          string | nil
  :align-raw          string | nil
  :valign-raw         string | nil
  :col-span-raw       string | nil
  :row-span-raw       string | nil
  :truncate?          boolean
  :sticky-raw         string | nil
  :sortable?          boolean
  :sort-direction-raw string | nil
  :disabled?          boolean

Output keys mirror the attribute semantics with parsed/normalised values.
sourceraw docstring

observed-attributescljs

source

parse-aligncljs

(parse-align s)

Normalise align attribute. Unknown/nil → "start".

Normalise align attribute. Unknown/nil → "start".
sourceraw docstring

parse-scopecljs

(parse-scope s)

Normalise scope attribute. Unknown/nil → "col".

Normalise scope attribute. Unknown/nil → "col".
sourceraw docstring

parse-sort-directioncljs

(parse-sort-direction s)

Normalise sort-direction attribute. Unknown/nil → "none".

Normalise sort-direction attribute. Unknown/nil → "none".
sourceraw docstring

parse-spancljs

(parse-span s)

Parse a col-span or row-span attribute to a positive integer. Invalid/nil → 1.

Parse a col-span or row-span attribute to a positive integer. Invalid/nil → 1.
sourceraw docstring

parse-stickycljs

(parse-sticky s)

Normalise sticky attribute. Unknown/nil → "none".

Normalise sticky attribute. Unknown/nil → "none".
sourceraw docstring

parse-typecljs

(parse-type s)

Normalise type attribute. Unknown/nil → "data".

Normalise type attribute. Unknown/nil → "data".
sourceraw docstring

parse-valigncljs

(parse-valign s)

Normalise valign attribute. Unknown/nil → "middle".

Normalise valign attribute. Unknown/nil → "middle".
sourceraw docstring

property-apicljs

source

role-for-cellcljs

(role-for-cell {:keys [type scope]})

Return the ARIA role string for the host element based on type and scope.

Return the ARIA role string for the host element based on type and scope.
sourceraw docstring

slot-sort-iconcljs

source

sort-btn-aria-labelcljs

(sort-btn-aria-label current-direction)

Return the aria-label for the sort button describing the action that will occur.

Return the aria-label for the sort button describing the action that will occur.
sourceraw docstring

sort-btn-tabindexcljs

(sort-btn-tabindex {:keys [type sortable? disabled?]})

Returns "0" when the sort button should be keyboard-focusable, else "-1".

Returns "0" when the sort button should be keyboard-focusable, else "-1".
sourceraw docstring

sort-btn-visible?cljs

(sort-btn-visible? {:keys [type sortable?]})

Sort button is visible only for header cells with sortable=true.

Sort button is visible only for header cells with sortable=true.
sourceraw docstring

tag-namecljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries