ClojureScript only.

baredom.requests

Generated by scripts/generate_types.bb from the event-schema of each model. Do not edit.

Generated by scripts/generate_types.bb from the event-schema of each model. Do not edit.
raw docstring

requestscljs

A map from each request event to the attributes it asks to change.

A map from each request event to the attributes it asks to change.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries