baremirror.alpha.element

An element with no state, made from a template.

An element with no state, made from a template.
raw docstring

baremirror.alpha.events

The DOM events of a page as messages for an application.

The DOM events of a page as messages for an application.
raw docstring

baremirror.alpha.js

The functions for JavaScript. JavaScript values go in and come out: a template is an array, attributes and containers are objects, and a hole is a function.

The functions for JavaScript. JavaScript values go in and come out: a template is an array,
attributes and containers are objects, and a hole is a function.
raw docstring

baremirror.alpha.parts

The nodes of templates, and the attributes and text of their parts.

The nodes of templates, and the attributes and text of their parts.
raw docstring

baremirror.alpha.places

The places of keyed nodes in the document. A key is a string, and a container is a parent with an optional :before anchor.

The places of keyed nodes in the document. A key is a string, and a container is a parent
with an optional `:before` anchor.
raw docstring

baremirror.alpha.plan

The plan that turns the current places into the wanted places.

The plan that turns the current places into the wanted places.
raw docstring

baremirror.alpha.template

The pure functions on templates. A template is a vector of a tag, an optional map of attributes, and children that are templates or text.

The pure functions on templates. A template is a vector of a tag, an optional map of
attributes, and children that are templates or text.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries