ClojureScript only.

baremirror.alpha.element

An element with no state, made from a template.

An element with no state, made from a template.
raw docstring

define-element!cljs

(define-element! tag {:keys [attrs css] element-template :template})

Registers tag as an element with no state: its shadow tree is :template, with each hole filled from the attributes named in :attrs, by keyword, and styled by :css. A tag that is already registered is left as it is.

Registers `tag` as an element with no state: its shadow tree is `:template`, with each hole
filled from the attributes named in `:attrs`, by keyword, and styled by `:css`.
A tag that is already registered is left as it is.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries