ClojureScript only.

baremirror.alpha.events

The DOM events of a page as messages for an application.

The DOM events of a page as messages for an application.
raw docstring

dispatchercljs

(dispatcher state step view render!)

A function of a message. It puts (step state message) into the state holder state, renders the view of what state then holds, and returns the new state.

A function of a message. It puts `(step state message)` into the state holder `state`,
renders the view of what `state` then holds, and returns the new state.
sourceraw docstring

listen!cljs

(listen! root {:keys [events] :as options})

Adds one listener to root for each event type in :events, which maps an event type and a part name to the meaning of a message for :dispatch!. :requests maps an event type to the attributes it asks to change: such an event is cancelled when its part shows the same of them after the dispatch as before.

Adds one listener to `root` for each event type in `:events`, which maps an event type and a
part name to the meaning of a message for `:dispatch!`. `:requests` maps an event type to the
attributes it asks to change: such an event is cancelled when its part shows the same of
them after the dispatch as before.
sourceraw docstring

read-origincljs

(read-origin e)

The origin of the event e: the keys on its path, outermost first, and the nearest part with its node. A part is looked for no further than the nearest keyed node, and the path exists only while the event is handled.

The origin of the event `e`: the keys on its path, outermost first, and the nearest part with
its node. A part is looked for no further than the nearest keyed node, and the path exists
only while the event is handled.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries