baremirror.alpha.places

The places of keyed nodes in the document. A key is a string, and a container is a parent with an optional :before anchor.

The places of keyed nodes in the document. A key is a string, and a container is a parent
with an optional `:before` anchor.
raw docstring

attr-keycljs

source

keyedcljs

(keyed node)

The key of node and the node, when it has a key.

The key of `node` and the node, when it has a key.
sourceraw docstring

perform!cljs

(perform! {:keys [containers nodes]}
          {removed :remove placements :place}
          make-node)

Performs plan on what read-places returned, with make-node making the node of a new key. Returns the node of each key that remains.

Performs `plan` on what `read-places` returned, with `make-node` making the node of a new key.
Returns the node of each key that remains.
sourceraw docstring

read-placescljs

(read-places containers)

The current places of containers, with the node of each key. A parent belongs to one container.

The current places of `containers`, with the node of each key.
A parent belongs to one container.
sourceraw docstring

release!cljs

(release! node)

Gives node up: it keeps its place in the document and loses its key.

Gives `node` up: it keeps its place in the document and loses its key.
sourceraw docstring

sync!cljs

(sync! containers wanted make-node)

Brings containers to the wanted places, with make-node making the node of a new key. Returns the node of each key that remains.

Brings `containers` to the `wanted` places, with `make-node` making the node of a new key.
Returns the node of each key that remains.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries