All platforms.

baremirror.alpha.plan

The plan that turns the current places into the wanted places.

The plan that turns the current places into the wanted places.
raw docstring

performclj/s

(perform places {removed :remove placements :place})

The places after plan is performed on places.

The places after `plan` is performed on `places`.
sourceraw docstring

planclj/s

(plan current wanted)

What must happen to turn the current places into the wanted places. Both map a container to its keys, in order. A key is in at most one container.

What must happen to turn the `current` places into the `wanted` places.
Both map a container to its keys, in order. A key is in at most one container.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries