baremirror.alpha.template

The pure functions on templates. A template is a vector of a tag, an optional map of attributes, and children that are templates or text.

The pure functions on templates. A template is a vector of a tag, an optional map of
attributes, and children that are templates or text.
raw docstring

attr-partclj/s

source

fixed?clj/s

(fixed? template)

True when the element of template can be made as it is: no :on entry, each attribute value text, a number, a boolean or nil, and each child a template, text or a number. The templates among its children are not looked at.

True when the element of `template` can be made as it is: no `:on` entry, each attribute value
text, a number, a boolean or nil, and each child a template, text or a number.
The templates among its children are not looked at.
sourceraw docstring

hole?clj/s

(hole? x)

True when x is a hole: a keyword or a function of the item.

True when `x` is a hole: a keyword or a function of the item.
sourceraw docstring

piecesclj/s

(pieces [tag & more])

The tag, the attributes and the children of template.

The tag, the attributes and the children of `template`.
sourceraw docstring

splitclj/s

(split template-name template)

Splits template: its fixed template under :fixed, its holes and its event meanings. A hole is an attribute value or the only child of an element, and :on maps an event type to a meaning.

Splits `template`: its fixed template under `:fixed`, its holes and its event meanings.
A hole is an attribute value or the only child of an element, and `:on` maps an event type
to a meaning.
sourceraw docstring

writesclj/s

(writes split-template item)

The writes of item for the holes of split-template, by part name.

The writes of `item` for the holes of `split-template`, by part name.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries