(build-plan total max-items items-before items-after)Return a map describing which items to display and where the ellipsis goes.
Returns: {:visible [0 1 4 5] ; indices of visible items in order :ellipsis-at 2 ; insert ellipsis before this position in :visible (-1 = none) :total 6}
Return a map describing which items to display and where the ellipsis goes.
Returns:
{:visible [0 1 4 5] ; indices of visible items in order
:ellipsis-at 2 ; insert ellipsis before this position in :visible (-1 = none)
:total 6}(normalize {:keys [separator-raw size-raw variant-raw wrap-raw max-items-raw
items-before-raw items-after-raw disabled-present?
preserve-aria-current-present? aria-label-raw
aria-describedby-raw]})(normalize-separator s)(parse-bool-attr s)(parse-pos-int s fallback)Parse string to positive integer ≥ 1, returning fallback on failure.
Parse string to positive integer ≥ 1, returning `fallback` on failure.
(parse-pos-int-or-nil s)Parse string to positive integer ≥ 1, returning nil on failure.
Parse string to positive integer ≥ 1, returning nil on failure.
(parse-size s)(parse-variant s)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |