(checkbox-value raw)Returns the raw value string, or "on" if nil.
Returns the raw value string, or "on" if nil.
(next-toggle-state checked? indeterminate?)Computes the next checked/indeterminate state after a user toggle.
Computes the next checked/indeterminate state after a user toggle.
(normalize {:keys [checked-present? indeterminate-present? disabled-present?
readonly-present? required-present? name-raw value-raw
aria-label-raw aria-describedby-raw aria-labelledby-raw]})Derives a complete view-model map from raw attribute presence/values.
Derives a complete view-model map from raw attribute presence/values.
(parse-bool-attr s)Returns true if the attribute is present and not equal to "false".
Returns true if the attribute is present and not equal to "false".
(valid? required? checked?)Returns true when the field satisfies its required constraint.
Returns true when the field satisfies its required constraint.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |