(effective-value label value-raw)Returns value-raw when it is a non-nil, non-empty string; else falls back to label.
Returns value-raw when it is a non-nil, non-empty string; else falls back to label.
(normalize {:keys [label-raw value-raw removable-raw disabled-present?]})Converts raw attribute strings to a clean view model. disabled-present? should be boolean: (.hasAttribute el attr-disabled)
Converts raw attribute strings to a clean view model. disabled-present? should be boolean: (.hasAttribute el attr-disabled)
(parse-bool-default-true s)nil (attribute absent) → true. 'false' or '0' → false. Anything else → true.
nil (attribute absent) → true. 'false' or '0' → false. Anything else → true.
(removal-eligible? {:keys [removable? disabled?]})True when the chip can be removed by the user: removable and not disabled.
True when the chip can be removed by the user: removable and not disabled.
(remove-detail {:keys [value label]})Builds the JS detail object for x-chip-remove events.
Builds the JS detail object for x-chip-remove events.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |