(normalize {:keys [name-raw value-raw currency-raw locale-raw min-raw max-raw
placeholder-raw label-raw hint-raw error-raw
disabled-present? required-present? readonly-present?]})Derives a complete view-model map from raw attribute values.
Derives a complete view-model map from raw attribute values.
(normalize-currency raw)(validation-message {:keys [value min max]})Returns a computed validation error string or empty string. Priority: badInput > rangeUnderflow > rangeOverflow.
Returns a computed validation error string or empty string. Priority: badInput > rangeUnderflow > rangeOverflow.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |