(normalize {:keys [legend-raw disabled-present? aria-label-raw
aria-describedby-raw]})Derives a complete view-model map from raw attribute values.
Derives a complete view-model map from raw attribute values.
(parse-bool-attr s)Returns true if attribute is present and not equal to "false".
Returns true if attribute is present and not equal to "false".
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |