(bool-attr? v)Returns true when attribute is present and not literally "false".
Returns true when attribute is present and not literally "false".
(normalize {:keys [loading-raw novalidate-raw autocomplete-raw]})Derives a complete view-model map from raw attribute values.
Derives a complete view-model map from raw attribute values.
(normalize-autocomplete raw)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |