app.components.x-select.model


allowed-sizescljs


attr-disabledcljs


attr-namecljs


attr-placeholdercljs


attr-requiredcljs


attr-sizecljs


attr-valuecljs


default-sizecljs


event-schemacljs


event-select-changecljs


normalizecljs

(normalize {:keys [disabled-present? required-present? size-raw placeholder-raw
                   value-raw name-raw]})

Derives a complete view-model map from raw attribute presence/values.

Derives a complete view-model map from raw attribute presence/values.
raw docstring

normalize-enumcljs

(normalize-enum value allowed default-value)

Returns value if it is in allowed, otherwise default-value.

Returns value if it is in allowed, otherwise default-value.
raw docstring

normalize-sizecljs

(normalize-size v)

observed-attributescljs


property-apicljs


tag-namecljs

cljdoc builds & hosts documentation for Clojure/Script libraries