(normalize {:keys [checked-present? disabled-present? readonly-present?
required-present? name-raw value-raw aria-label-raw
aria-describedby-raw aria-labelledby-raw]})Derives a complete view-model map from raw attribute presence/values.
Input keys: :checked-present? boolean :disabled-present? boolean :readonly-present? boolean :required-present? boolean :name-raw string | nil :value-raw string | nil :aria-label-raw string | nil :aria-describedby-raw string | nil :aria-labelledby-raw string | nil
Output keys: :checked? boolean :disabled? boolean :readonly? boolean :required? boolean :valid? boolean :name string | nil :value string :aria-label string | nil :aria-describedby string | nil :aria-labelledby string | nil :aria-checked "true" | "false"
Derives a complete view-model map from raw attribute presence/values. Input keys: :checked-present? boolean :disabled-present? boolean :readonly-present? boolean :required-present? boolean :name-raw string | nil :value-raw string | nil :aria-label-raw string | nil :aria-describedby-raw string | nil :aria-labelledby-raw string | nil Output keys: :checked? boolean :disabled? boolean :readonly? boolean :required? boolean :valid? boolean :name string | nil :value string :aria-label string | nil :aria-describedby string | nil :aria-labelledby string | nil :aria-checked "true" | "false"
(parse-bool-attr s)Returns true if the attribute is present (non-nil) and not equal to "false".
Returns true if the attribute is present (non-nil) and not equal to "false".
(switch-value raw)Returns the raw value string, or "on" if nil.
Returns the raw value string, or "on" if nil.
(valid? required? checked?)Returns true when the field satisfies its required constraint.
Returns true when the field satisfies its required constraint.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |