app.components.x-toaster.model


attr-labelcljs


attr-max-toastscljs


attr-positioncljs


bottom-position?cljs

(bottom-position? position)

Returns true when position places the toaster at the bottom of the viewport.

Returns true when position places the toaster at the bottom of the viewport.
raw docstring

center-position?cljs

(center-position? position)

Returns true when position uses horizontal centering.

Returns true when position uses horizontal centering.
raw docstring

child-dismiss-reason-toastercljs


child-event-dismisscljs


child-tagcljs


dismiss-detailcljs

(dismiss-detail type reason heading message)

Build event detail map for x-toaster-dismiss from the child x-toast-dismiss detail.

Build event detail map for x-toaster-dismiss from the child x-toast-dismiss detail.
raw docstring

event-dismisscljs


event-schemacljs


normalizecljs

(normalize {:keys [position-raw max-toasts-raw label-raw]})

Produce a stable view-model map from raw attribute inputs.

Input keys: :position-raw string | nil :max-toasts-raw string | nil :label-raw string | nil

Output keys: :position string — one of the six valid position values :max-toasts number — positive integer (default 5) :label string — aria-label for the region (default "Notifications")

Produce a stable view-model map from raw attribute inputs.

Input keys:
  :position-raw    string | nil
  :max-toasts-raw  string | nil
  :label-raw       string | nil

Output keys:
  :position   string — one of the six valid position values
  :max-toasts number — positive integer (default 5)
  :label      string — aria-label for the region (default "Notifications")
raw docstring

observed-attributescljs


parse-max-toastscljs

(parse-max-toasts s)

Parse max-toasts to a positive integer; fallback to 5.

Parse max-toasts to a positive integer; fallback to 5.
raw docstring

parse-positioncljs

(parse-position s)

Normalise position attribute to a valid enum value; fallback to "top-end".

Normalise position attribute to a valid enum value; fallback to "top-end".
raw docstring

property-apicljs


tag-namecljs

cljdoc builds & hosts documentation for Clojure/Script libraries