(bottom-position? position)Returns true when position places the toaster at the bottom of the viewport.
Returns true when position places the toaster at the bottom of the viewport.
(center-position? position)Returns true when position uses horizontal centering.
Returns true when position uses horizontal centering.
(dismiss-detail type reason heading message)Build event detail map for x-toaster-dismiss from the child x-toast-dismiss detail.
Build event detail map for x-toaster-dismiss from the child x-toast-dismiss detail.
(normalize {:keys [position-raw max-toasts-raw label-raw]})Produce a stable view-model map from raw attribute inputs.
Input keys: :position-raw string | nil :max-toasts-raw string | nil :label-raw string | nil
Output keys: :position string — one of the six valid position values :max-toasts number — positive integer (default 5) :label string — aria-label for the region (default "Notifications")
Produce a stable view-model map from raw attribute inputs. Input keys: :position-raw string | nil :max-toasts-raw string | nil :label-raw string | nil Output keys: :position string — one of the six valid position values :max-toasts number — positive integer (default 5) :label string — aria-label for the region (default "Notifications")
(parse-max-toasts s)Parse max-toasts to a positive integer; fallback to 5.
Parse max-toasts to a positive integer; fallback to 5.
(parse-position s)Normalise position attribute to a valid enum value; fallback to "top-end".
Normalise position attribute to a valid enum value; fallback to "top-end".
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |