(normalize-order v)Parse order attribute to integer, or nil if absent/invalid.
Parse order attribute to integer, or nil if absent/invalid.
(normalize-span v)Parse span attribute to integer clamped 1–6, default 1.
Parse span attribute to integer clamped 1–6, default 1.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |