baredom.components.x-date-picker.model


attr-aria-describedbycljs

source

attr-aria-labelcljs

source

attr-auto-swapcljs

source

attr-autocompletecljs

source

attr-close-on-selectcljs

source

attr-disabledcljs

source

attr-endcljs

source

attr-formatcljs

source

attr-localecljs

source

attr-maxcljs

source

attr-mincljs

source

attr-modecljs

source

attr-namecljs

source

attr-placeholdercljs

source

attr-range-allow-samecljs

source

attr-readonlycljs

source

attr-requiredcljs

source

attr-separatorcljs

source

attr-startcljs

source

attr-valuecljs

source

canonicalizecljs

(canonicalize {:keys [mode value start end min max format locale separator
                      auto-swap? range-allow-same-day?]})

Build stable model from raw attr strings.

Build stable model from raw attr strings.
sourceraw docstring

display-valuecljs

(display-value canon {:keys [format locale]})

Compute the input display string from canonicalized state.

Compute the input display string from canonicalized state.
sourceraw docstring

event-changecljs

source

event-change-requestcljs

source

event-inputcljs

source

event-schemacljs

source

format-datecljs

(format-date d {:keys [format locale]})

Format a JS Date for display. Uses Intl.DateTimeFormat when available.

Format a JS Date for display.  Uses Intl.DateTimeFormat when available.
sourceraw docstring

method-apicljs

source

normalize-strcljs

(normalize-str s)

Trim and return nil if empty.

Trim and return nil if empty.
sourceraw docstring

observed-attributescljs

source

parse-display->rangecljs

(parse-display->range display {:keys [separator]})

Try to parse a display string that may contain a separator. Returns {:ok? boolean :start js/Date|nil :end js/Date|nil}.

Try to parse a display string that may contain a separator.
Returns {:ok? boolean :start js/Date|nil :end js/Date|nil}.
sourceraw docstring

parse-display->singlecljs

(parse-display->single display)

Try to parse a display string to a single date. Accepts ISO "YYYY-MM-DD". Returns {:ok? boolean :date js/Date|nil}.

Try to parse a display string to a single date.
Accepts ISO "YYYY-MM-DD". Returns {:ok? boolean :date js/Date|nil}.
sourceraw docstring

parse-formatcljs

(parse-format s)

Returns :iso or :localized. Default is :iso.

Returns :iso or :localized.  Default is :iso.
sourceraw docstring

parse-intcljs

(parse-int s default-v)

Parse integer string, returning default-v on failure.

Parse integer string, returning default-v on failure.
sourceraw docstring

parse-modecljs

(parse-mode s)

Returns :single or :range. Default is :single.

Returns :single or :range.  Default is :single.
sourceraw docstring

property-apicljs

source

tag-namecljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries