(canonicalize {:keys [mode value start end min max format locale separator
auto-swap? range-allow-same-day?]})Build stable model from raw attr strings.
Build stable model from raw attr strings.
(display-value canon {:keys [format locale]})Compute the input display string from canonicalized state.
Compute the input display string from canonicalized state.
(format-date d {:keys [format locale]})Format a JS Date for display. Uses Intl.DateTimeFormat when available.
Format a JS Date for display. Uses Intl.DateTimeFormat when available.
(normalize-str s)Trim and return nil if empty.
Trim and return nil if empty.
(parse-display->range display {:keys [separator]})Try to parse a display string that may contain a separator. Returns {:ok? boolean :start js/Date|nil :end js/Date|nil}.
Try to parse a display string that may contain a separator.
Returns {:ok? boolean :start js/Date|nil :end js/Date|nil}.(parse-display->single display)Try to parse a display string to a single date. Accepts ISO "YYYY-MM-DD". Returns {:ok? boolean :date js/Date|nil}.
Try to parse a display string to a single date.
Accepts ISO "YYYY-MM-DD". Returns {:ok? boolean :date js/Date|nil}.(parse-format s)Returns :iso or :localized. Default is :iso.
Returns :iso or :localized. Default is :iso.
(parse-int s default-v)Parse integer string, returning default-v on failure.
Parse integer string, returning default-v on failure.
(parse-mode s)Returns :single or :range. Default is :single.
Returns :single or :range. Default is :single.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |