(needs-fetch? old-m new-m)Returns true when the locale or src changed between old and new models, indicating a new fetch is required.
Returns true when the locale or src changed between old and new models, indicating a new fetch is required.
(normalize src locale fallback-locale)Normalize raw attribute values into a model map.
Normalize raw attribute values into a model map.
(resolve-url src locale)Replace {locale} in the src pattern with the given locale.
Returns nil if src or locale is blank.
Replace `{locale}` in the src pattern with the given locale.
Returns nil if src or locale is blank.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |