(get-translations el)Returns the translations object stored on the provider element. Used by x-i18n children to resolve translation keys.
Returns the translations object stored on the provider element. Used by x-i18n children to resolve translation keys.
(set-translations! el translations)Set translations on the provider element. Used by tests and for programmatic locale injection.
Set translations on the provider element. Used by tests and for programmatic locale injection.
(translate-subtree! el)Scan all descendants for data-i18n-{attr} attributes and set the corresponding real attribute from the current translations. Skips elements owned by nested x-i18n-provider elements.
Scan all descendants for data-i18n-{attr} attributes and set the
corresponding real attribute from the current translations.
Skips elements owned by nested x-i18n-provider elements.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |