(create-entities width height count _variant char-sz)Create an array of column entities for matrix rain.
char-sz sets the font size used for spacing calculations.
Create an array of column entities for matrix rain. `char-sz` sets the font size used for spacing calculations.
(draw! ctx columns _width height colors _time)Render matrix rain columns to a 2D canvas context.
Render matrix rain columns to a 2D canvas context.
(draw-static! ctx columns width height colors)Render a single static frame (prefers-reduced-motion).
Render a single static frame (prefers-reduced-motion).
(update-entities! columns dt speed-multiplier _width height _variant)Update column positions and randomly change characters.
Update column positions and randomly change characters.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |