(compute-duration-s speed)Compute animation duration in seconds: base / speed.
Compute animation duration in seconds: base / speed.
(derive-state {:keys [text path preset animation speed direction effect
font-size start-size end-size repeat echo-count echo-delay
echo-opacity echo-scale]})Master normalisation: raw attribute map -> stable view-model.
Master normalisation: raw attribute map -> stable view-model.
(parse-effects s)Parse a space-separated effect string into a set of valid effect tokens.
Parse a space-separated effect string into a set of valid effect tokens.
(resolve-path custom-path preset)Returns {:d "..." :view-box "..."} from custom path or preset. Returns nil for crawl preset (no SVG path needed).
Returns {:d "..." :view-box "..."} from custom path or preset.
Returns nil for crawl preset (no SVG path needed).cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |