baredom.components.x-otp-input.model


allowed-typescljs

source

attr-autofocuscljs

source

attr-disabledcljs

source

attr-errorcljs

source

attr-labelcljs

source

attr-lengthcljs

source

attr-maskcljs

source

attr-namecljs

source

attr-placeholdercljs

source

attr-readonlycljs

source

attr-requiredcljs

source

attr-typecljs

source

attr-valuecljs

source

clamp-lengthcljs

(clamp-length n)
source

complete?cljs

(complete? value length)

True when value has exactly length characters.

True when value has exactly `length` characters.
sourceraw docstring

default-lengthcljs

source

default-typecljs

source

event-changecljs

source

event-completecljs

source

event-inputcljs

source

event-schemacljs

source

filter-charscljs

(filter-chars type-name s)

Remove characters that are not allowed for the given OTP type.

Remove characters that are not allowed for the given OTP type.
sourceraw docstring

max-length-capcljs

source

method-apicljs

source

min-lengthcljs

source

normalizecljs

(normalize {:keys [name-raw value-raw length-raw type-raw mask-present?
                   disabled-present? readonly-present? required-present?
                   autofocus-present? label-raw placeholder-raw error-raw]})

Derive a complete view-model map from raw attribute values.

Derive a complete view-model map from raw attribute values.
sourceraw docstring

normalize-valuecljs

(normalize-value type-name length raw)

Filter and truncate a raw value string for the given OTP type and length.

Filter and truncate a raw value string for the given OTP type and length.
sourceraw docstring

observed-attributescljs

source

parse-lengthcljs

(parse-length raw)

Parse the length attribute. Empty / non-numeric falls back to default-length. Numeric values are clamped to [min-length, max-length-cap].

Parse the `length` attribute. Empty / non-numeric falls back to default-length.
Numeric values are clamped to [min-length, max-length-cap].
sourceraw docstring

parse-typecljs

(parse-type raw)

Parse the type attribute. Unknown / nil falls back to default-type.

Parse the `type` attribute. Unknown / nil falls back to default-type.
sourceraw docstring

placeholder-charcljs

(placeholder-char raw)

Return the single-character placeholder, or empty string.

Return the single-character placeholder, or empty string.
sourceraw docstring

property-apicljs

source

slot-aria-labelcljs

(slot-aria-label type-name index length)

Build the per-slot aria-label string.

Build the per-slot aria-label string.
sourceraw docstring

slot-inputmodecljs

(slot-inputmode type-name)

Map OTP type to the slot input inputmode attribute.

Map OTP `type` to the slot input `inputmode` attribute.
sourceraw docstring

tag-namecljs

source

truncatecljs

(truncate s n)

Trim a string to at most n characters.

Trim a string to at most `n` characters.
sourceraw docstring

type-alphacljs

source

type-alphanumericcljs

source

type-numericcljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries