(mode-physics mode)Returns physics configuration for a given mode.
Returns physics configuration for a given mode.
(particle-lifetime-range ptype mode)Returns [min-ms max-ms] for a particle type and mode.
Returns [min-ms max-ms] for a particle type and mode.
(particle-opacity-range ptype mode)Returns [min max] opacity for a particle type and mode.
Returns [min max] opacity for a particle type and mode.
(particle-size-range ptype base-size mode)Returns [min-size max-size] for a particle type given base particle-size and mode.
Returns [min-size max-size] for a particle type given base particle-size and mode.
(pick-particle-type rand-val mode-cfg)Returns type-dust, type-fragment, or type-streak based on mode ratios.
Returns type-dust, type-fragment, or type-streak based on mode ratios.
(press-burst-velocity px py bw bh base-speed spread rand-angle rand-speed)Compute [vx vy] for a particle emitted from (px,py) with base-speed, spread half-angle, and random values [0,1).
Compute [vx vy] for a particle emitted from (px,py) with base-speed, spread half-angle, and random values [0,1).
(public-state {:keys [disabled loading pressed type variant size label mode
particle-count intensity particle-size reassemble-speed]})(random-edge-point w h rand-val)Given button width w and height h and a random value [0,1), returns [x y nx ny] where (x,y) is on the perimeter and (nx,ny) is the outward normal.
Given button width w and height h and a random value [0,1), returns [x y nx ny] where (x,y) is on the perimeter and (nx,ny) is the outward normal.
(variant-visuals variant)Returns visual-only configuration for a variant. Particle behavior is now controlled by mode, not variant.
Returns visual-only configuration for a variant. Particle behavior is now controlled by mode, not variant.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |