baredom.utils.dom


define-bool-prop!cljs

(define-bool-prop! proto prop-name attr-name)

Install a boolean JS property that reflects to/from an HTML attribute.

Install a boolean JS property that reflects to/from an HTML attribute.
sourceraw docstring

define-number-prop!cljs

(define-number-prop! proto prop-name attr-name default-val)

Install a numeric JS property that reflects to/from an HTML attribute. default-val is returned when the attribute is absent or non-numeric.

Install a numeric JS property that reflects to/from an HTML attribute.
`default-val` is returned when the attribute is absent or non-numeric.
sourceraw docstring

define-string-prop!cljs

(define-string-prop! proto prop-name attr-name)
(define-string-prop! proto prop-name attr-name default-val)

Install a string JS property that reflects to/from an HTML attribute. default-val is returned when the attribute is absent (defaults to nil).

Install a string JS property that reflects to/from an HTML attribute.
`default-val` is returned when the attribute is absent (defaults to nil).
sourceraw docstring

dispatch!cljs

(dispatch! el event-name detail)

Dispatch a non-cancelable CustomEvent that bubbles and is composed.

Dispatch a non-cancelable CustomEvent that bubbles and is composed.
sourceraw docstring

dispatch-cancelable!cljs

(dispatch-cancelable! el event-name detail)

Dispatch a cancelable CustomEvent. Returns true when NOT cancelled.

Dispatch a cancelable CustomEvent. Returns true when NOT cancelled.
sourceraw docstring

get-attrcljs

(get-attr el attr-name)
source

getvcljs

(getv el k)
source

has-attr?cljs

(has-attr? el attr-name)
source

initialized?cljs

(initialized? el key)
source

install-properties!cljs

(install-properties! proto property-api)

Install JS property accessors on a prototype, driven by a property-api map. Each entry is {prop-key {:type 'boolean|'string|'number :reflects-attribute attr-name :default default-val}}. Skips entries marked :readonly true.

Install JS property accessors on a prototype, driven by a property-api map.
Each entry is {prop-key {:type 'boolean|'string|'number
                         :reflects-attribute attr-name
                         :default default-val}}.
Skips entries marked :readonly true.
sourceraw docstring

mark-initialized!cljs

(mark-initialized! el key)
source

remove-attr!cljs

(remove-attr! el attr-name)
source

set-attr!cljs

(set-attr! el attr-name value)
source

set-bool-attr!cljs

(set-bool-attr! el attr-name value)
source

setv!cljs

(setv! el k v)
source

cljdoc builds & hosts documentation for Clojure/Script libraries