baredom.utils.model


non-empty-string?cljs

(non-empty-string? value)
source

parse-bool-attrcljs

(parse-bool-attr s)
source

parse-bool-presentcljs

(parse-bool-present s)
source

safe-url?cljs

(safe-url? url)

Returns true when url uses an allowed protocol or is a relative URL.

Returns true when url uses an allowed protocol or is a relative URL.
sourceraw docstring

sanitize-svg-path-dcljs

(sanitize-svg-path-d s)

Strips characters that are not valid in an SVG path d-attribute. Returns nil if the result is blank.

Strips characters that are not valid in an SVG path d-attribute.
Returns nil if the result is blank.
sourceraw docstring

sanitize-urlcljs

(sanitize-url url)

Returns url when safe, empty string otherwise.

Returns url when safe, empty string otherwise.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries