(safe-url? url)Returns true when url uses an allowed protocol or is a relative URL.
Returns true when url uses an allowed protocol or is a relative URL.
(sanitize-svg-path-d s)Strips characters that are not valid in an SVG path d-attribute. Returns nil if the result is blank.
Strips characters that are not valid in an SVG path d-attribute. Returns nil if the result is blank.
(sanitize-url url)Returns url when safe, empty string otherwise.
Returns url when safe, empty string otherwise.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |