The plan that turns the current places into the wanted places.
The plan that turns the current places into the wanted places.
(perform places {removed :remove placements :place})The places after plan is performed on places.
The places after `plan` is performed on `places`.
(plan current wanted)What must happen to turn the current places into the wanted places.
Both map a container to its keys, in order. A key is in at most one container.
What must happen to turn the `current` places into the `wanted` places. Both map a container to its keys, in order. A key is in at most one container.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |